# mypy-boto3-ses

[![PyPI - mypy-boto3-ses](https://img.shields.io/pypi/v/mypy-boto3-ses.svg?color=blue)](https://pypi.org/project/mypy-boto3-ses)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-ses.svg?color=blue)](https://pypi.org/project/mypy-boto3-ses)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.SES 1.14.55](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/ses.html#SES) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.0.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-ses](#mypy-boto3-ses)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `SES` service.

```bash
python -m pip install boto3-stubs[ses]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[ses]` in your environment: `python -m pip install 'boto3-stubs[ses]'`

Both type checking and auto-complete should work for `SES` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[ses]` in your environment: `python -m pip install 'boto3-stubs[ses]'`

Both type checking and auto-complete should work for `SES` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[ses]` in your environment: `python -m pip install 'boto3-stubs[ses]'`
- Run `mypy` as usual

Type checking should work for `SES` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[ses]` in your environment: `python -m pip install 'boto3-stubs[ses]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `SES` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`SESClient` provides annotations for `boto3.client("ses")`.

```python
import boto3

from mypy_boto3_ses import SESClient

client: SESClient = boto3.client("ses")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SESClient = session.client("ses")
```

### Paginators annotations

`mypy_boto3_ses.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_ses import SESClient
from mypy_boto3_ses.paginator import (
    ListConfigurationSetsPaginator,
    ListCustomVerificationEmailTemplatesPaginator,
    ListIdentitiesPaginator,
    ListReceiptRuleSetsPaginator,
    ListTemplatesPaginator,
)

client: SESClient = boto3.client("ses")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_configuration_sets_paginator: ListConfigurationSetsPaginator = client.get_paginator("list_configuration_sets")
list_custom_verification_email_templates_paginator: ListCustomVerificationEmailTemplatesPaginator = client.get_paginator("list_custom_verification_email_templates")
list_identities_paginator: ListIdentitiesPaginator = client.get_paginator("list_identities")
list_receipt_rule_sets_paginator: ListReceiptRuleSetsPaginator = client.get_paginator("list_receipt_rule_sets")
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
```


### Waiters annotations

`mypy_boto3_ses.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_ses import SESClient
from mypy_boto3_ses.waiter import IdentityExistsWaiter

client: SESClient = boto3.client("ses")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
identity_exists_waiter: IdentityExistsWaiter = client.get_waiter("identity_exists")
```





### Typed dictionations

`mypy_boto3_ses.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_ses.type_defs import (
    AddHeaderActionTypeDef,
    BodyTypeDef,
    BounceActionTypeDef,
    BouncedRecipientInfoTypeDef,
    BulkEmailDestinationStatusTypeDef,
    BulkEmailDestinationTypeDef,
    CloudWatchDestinationTypeDef,
    CloudWatchDimensionConfigurationTypeDef,
    ConfigurationSetTypeDef,
    ContentTypeDef,
    CustomVerificationEmailTemplateTypeDef,
    DeliveryOptionsTypeDef,
    DescribeActiveReceiptRuleSetResponseTypeDef,
    DescribeConfigurationSetResponseTypeDef,
    DescribeReceiptRuleResponseTypeDef,
    DescribeReceiptRuleSetResponseTypeDef,
    DestinationTypeDef,
    EventDestinationTypeDef,
    ExtensionFieldTypeDef,
    GetAccountSendingEnabledResponseTypeDef,
    GetCustomVerificationEmailTemplateResponseTypeDef,
    GetIdentityDkimAttributesResponseTypeDef,
    GetIdentityMailFromDomainAttributesResponseTypeDef,
    GetIdentityNotificationAttributesResponseTypeDef,
    GetIdentityPoliciesResponseTypeDef,
    GetIdentityVerificationAttributesResponseTypeDef,
    GetSendQuotaResponseTypeDef,
    GetSendStatisticsResponseTypeDef,
    GetTemplateResponseTypeDef,
    IdentityDkimAttributesTypeDef,
    IdentityMailFromDomainAttributesTypeDef,
    IdentityNotificationAttributesTypeDef,
    IdentityVerificationAttributesTypeDef,
    KinesisFirehoseDestinationTypeDef,
    LambdaActionTypeDef,
    ListConfigurationSetsResponseTypeDef,
    ListCustomVerificationEmailTemplatesResponseTypeDef,
    ListIdentitiesResponseTypeDef,
    ListIdentityPoliciesResponseTypeDef,
    ListReceiptFiltersResponseTypeDef,
    ListReceiptRuleSetsResponseTypeDef,
    ListTemplatesResponseTypeDef,
    ListVerifiedEmailAddressesResponseTypeDef,
    MessageDsnTypeDef,
    MessageTagTypeDef,
    MessageTypeDef,
    PaginatorConfigTypeDef,
    RawMessageTypeDef,
    ReceiptActionTypeDef,
    ReceiptFilterTypeDef,
    ReceiptIpFilterTypeDef,
    ReceiptRuleSetMetadataTypeDef,
    ReceiptRuleTypeDef,
    RecipientDsnFieldsTypeDef,
    ReputationOptionsTypeDef,
    S3ActionTypeDef,
    SendBounceResponseTypeDef,
    SendBulkTemplatedEmailResponseTypeDef,
    SendCustomVerificationEmailResponseTypeDef,
    SendDataPointTypeDef,
    SendEmailResponseTypeDef,
    SendRawEmailResponseTypeDef,
    SendTemplatedEmailResponseTypeDef,
    SNSActionTypeDef,
    SNSDestinationTypeDef,
    StopActionTypeDef,
    TemplateMetadataTypeDef,
    TemplateTypeDef,
    TestRenderTemplateResponseTypeDef,
    TrackingOptionsTypeDef,
    VerifyDomainDkimResponseTypeDef,
    VerifyDomainIdentityResponseTypeDef,
    WaiterConfigTypeDef,
    WorkmailActionTypeDef,
)


def get_structure() -> AddHeaderActionTypeDef:
    return {
      ...
    }
```
